Ideas for future versions of xatk
=================================

-  add keybindings to quit xatk, reload config and update history in the
   config;
-  generate dump files on unhandled exceptions;
-  alt-tab-like behaviour for cycling shortcuts for grouped windows
   (more recently used windows are raised first);
-  revert states of the windows while cycling (e.g. iconify them if they
   were iconified before);
-  user-defined keyboard layouts;
-  provide current list of windows and corresponding shortcuts (via pipe
   or a regular file?);
-  make program's name as another source to form awns;
-  prevent updating window names too often.
